@@ -35,4 +35,7 @@ GERAPY_PYPPETEER_DISABLE_GPU = True
 # ``stylesheet``, ``image``, ``media``, ``font``, ``script``,
 #  ``texttrack``, ``xhr``, ``fetch``, ``eventsource``, ``websocket``,
 #  ``manifest``, ``other``.
-GERAPY_IGNORE_RESOURCE_TYPES = []
+GERAPY_PYPPETEER_IGNORE_RESOURCE_TYPES = []
+
+GERAPY_PYPPETEER_SCREENSHOT = None
+GERAPY_PYPPETEER_SLEEP = 1
